@@ -174,6 +174,7 @@ class EFTemplateResolver(object):
       {{ENV}}           - environment: mgmt, prod, staging, proto<N>, etc.
       {{ENV_SHORT}}     - env with <N> or account trimmed: mgmt, prod, staging, proto, etc.
       {{ENV_FULL}}      - env fully qualified: prod, staging, proto<N>, mgmt.<account_alias>, etc.
+      {{ENV_NEW}}       - parallel new env name
       {{FUNCTION_NAME}} - only for lambdas
       {{INSTANCE_ID}}   - only for ec2
       {{REGION}}        - the region currently being worked in
@@ -188,6 +189,7 @@ class EFTemplateResolver(object):
         "ACCOUNT": None,
         "ACCOUNT_ALIAS": None,
         "ENV": None,
+        "ENV_NEW": None,
         "ENV_SHORT": None,
         "ENV_FULL": None,
         "FUNCTION_NAME": None,
@@ -321,6 +323,11 @@ class EFTemplateResolver(object):
     else:
       self.resolved["ENV_FULL"] = self.resolved["ENV"]
 
+    if self.resolved["ENV_SHORT"] in EFConfig.NEW_ENV_MAP:
+        self.resolved["ENV_NEW"] = EFConfig.NEW_ENV_MAP[self.resolved["ENV_SHORT"]]
+    else:
+        self.resolved["ENV_NEW"] = self.resolved["ENV_SHORT"]
+
     if self.verbose:
       print(repr(self.resolved), file=sys.stderr)
 
@@ -454,6 +461,8 @@ class EFTemplateResolver(object):
           if isinstance(resolved_symbol, list):
             # Using old style of string formatting here due to str.format() interaction with curly braces
             self.template = re.sub(r'{{\.?%s}}' % re.escape(symbol), "\n".join(resolved_symbol), self.template)
+          elif resolved_symbol.lower() == "novalue":
+            self.template = re.sub(r'"{{\.?%s}}"' % re.escape(symbol), '{ "Ref": "AWS::NoValue" }', self.template)
           else:
             self.template = re.sub(r'{{\.?%s}}' % re.escape(symbol), resolved_symbol, self.template)
           go_again = True
